# -*- coding: utf-8 -*-
"""
Created on Wed Apr 20 13:55:47 2022

@author: Fanfan
"""
#####理想聚类 ideal clustering (idc)#####

import numpy as np 

import math  

import pandas as pd
import win32ui


def idc():
    input("提示：按回车键开始选择待学习的数据！")
    
    
    dlg = win32ui.CreateFileDialog(1)
    dlg.SetOFNInitialDir('C:/')
    dlg.DoModal()
    filename = dlg.GetPathName()
    arr = pd.read_csv(filename).values
    
    
    
    enter=input("提示：输入真实的分类数量，并按回车键继续！")
    num_class=int(enter)
    
    data={}
    for num in range(1,num_class+1):
        lists=[]
        classname0='class'+str(num)+'name'
        classname0=input('提示：输入分类'+str(num)+'所属分类类别名称，按回车键继续！')    
        classname1='class'+str(num)+'start'
        classname1=input('提示：分类'+str(num)+'开始行索引，按回车键继续！')
        classname2='class'+str(num)+'end'
        classname2=input('提示：分类'+str(num)+'结束行索引，按回车键继续！')
        lists.append(int(classname1))
        lists.append(int(classname2))
        data[classname0]=lists
    #print(data)
    
    dic1={}
    for k,v in data.items():
        dic1[k]=arr[v[0]:v[1],:]
    print(dic1)
    
    
    
    
    
    
    
    
    
    
    input("提示：请确保测试数据具有和学习数据相同的特征列，并按回车键继续！")
    dlg1 = win32ui.CreateFileDialog(1)
    dlg1.SetOFNInitialDir('C:/')
    dlg1.DoModal()
    filename1 = dlg1.GetPathName()
    p2 = pd.read_csv(filename1).values
    #print(p2)
    print("测试数据聚类结果按行显示：") 
    
        
    for ii in range(len(p2)):
        dic2={}
               
        diss=[]        
        
        for k,v in dic1.items():
            dist=[]
            for vv in v:
                list2=[]
                
                for i in range(len(p2[0])):            
                    d=(vv[i]-p2[ii][i])**2
                    list2.append(d)
                dd=sum(list2)
                dis=np.sqrt(dd)
                diss.append(dis)
                dist.append(dis)
                #print(len(dist))
                dic2[k]=dist 
        #print("测试数据聚类结果按行显示：")
        for ks,vs in dic2.items():
            if(min(diss) in vs):
                print(ks)
        
  
















# Copyright 2024 idc_clustering(https://gitee.com/hai_li_de/gitee-clustering.git). All Rights Reserved.
#
# Licensed under the Apache License, Version 1.3.5 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import setuptools
import pathlib

here = pathlib.Path(__file__).parent.resolve()
long_description = (here / "README.md").read_text(encoding="utf-8")

setuptools.setup(
    name="idc_clustering",
    version="1.3.5",
    author="idc_clustering",
    author_email="1262043823@qq.com",
    description="A clustering library that can return which cluster it belongs to",
    long_description="A clustering library that can learn based on historical data and classification labels."
                " The current version can only test and classify a set of data. "
                "The test classification of batch data will be updated later, "
                "and will return which historical learning data the test data belongs to. Classification tags",
    long_description_content_type="text/markdown",
    url="https://gitee.com/hai_li_de/gitee-clustering.git",
    packages=['idc_clustering'],
    install_requires=['pydantic', 'cushy-storage'],
    python_requires='>=3.6',
    license="Apache 2.0",
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3 :: Only",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",

    ],
    keywords="idc_clustering, clustering-service, Return to category tags",
)